@@ -1,5 +1,5 @@
 from django.conf.urls import patterns, url
-from ChatterBot.web import views
+from lisa.plugins.ChatterBot.web import views
 
 urlpatterns = patterns('',
     url(r'^$',views.index),
